Add any missing BLUtag hits to the hitsBlu table in an existing Motus
database. hitsBlu contain extra information regarding the 'health' of
portable node units. Use getBluPayload() to extract these details from
the payload data.
Details
This function is only required if you suspect BLUtag hits have been missed (due to hits being downloaded before the motus package had the functionality to download BLUtag hits).